@@ -36,6 +36,13 @@ pub fn gen_enum(def: &TypeDef, gen: &Gen, include: TypeInclude) -> TokenStream {
                     self.0.bitand_assign(rhs.0)
                 }
             }
+            impl ::std::ops::Not for #name {
+                type Output = Self;
+
+                fn not(self) -> Self {
+                    Self(self.0.not())
+                }
+            }
         }
     } else {
         quote! {}
@@ -106,6 +113,8 @@ pub fn gen_enum(def: &TypeDef, gen: &Gen, include: TypeInclude) -> TokenStream {
         quote! {}
     };
 
+    let extensions = gen_extensions(def);
+
     quote! {
         #[derive(::std::cmp::PartialEq, ::std::cmp::Eq, ::std::marker::Copy, ::std::clone::Clone, ::std::default::Default, ::std::fmt::Debug)]
         #[repr(transparent)]
@@ -122,6 +131,14 @@ pub fn gen_enum(def: &TypeDef, gen: &Gen, include: TypeInclude) -> TokenStream {
         }
         #runtime_type
         #bitwise
+        #extensions
+    }
+}
+
+fn gen_extensions(def: &TypeDef) -> TokenStream {
+    match def.type_name() {
+        TypeName::WIN32_ERROR => gen_win32_error(),
+        _ => TokenStream::new(),
     }
 }
 
